@@ -2,13 +2,15 @@ from zipfile import ZipFile
 from nonebot.log import logger
 import requests
 import os
-
+from pathlib import Path
 def get_file(url,down_file):
+    '''
+    下载指定Url到指定位置
+    '''
     try:
         maps = requests.get(url)
         logger.info('已获取文件，尝试新建文件并写入')
         with open(down_file ,'wb') as mfile:
-            logger.info('正在写入')
             mfile.write(maps.content)
             logger.info('下载成功')
             mes =('文件已下载,正在解压')
@@ -19,6 +21,9 @@ def get_file(url,down_file):
     return mes
 
 def get_vpk(vpk_list:list,path):
+    '''
+    获取所有vpk文件
+    '''
     for file in os.listdir(path):
         if file.endswith('.vpk'):
             vpk_list.append(file)
@@ -43,4 +48,30 @@ def support_gbk(zip_file: ZipFile):
             info.filename = real_name
             del name_to_info[name]
             name_to_info[real_name] = info
-    return zip_file
\ No newline at end of file
+    return zip_file
+
+def del_map(num,map_path):
+    '''
+    删除指定的地图
+    '''
+    vpk_list = []
+    map = get_vpk(vpk_list,map_path)
+    map_name = map[int(num)-1].decode('utf-8') 
+    del_file = Path(map_path,map_name)
+    os.remove(del_file)
+    return map_name
+
+def rename_map(num,rename,map_path):
+    '''
+    改名指定的地图
+    '''
+    vpk_list = []
+    name = str(rename)
+    map = get_vpk(vpk_list,map_path)
+    logger.info('文件名解码')
+    map_name = map[int(num)-1]
+    logger.info('解码成功')
+    old_file = Path(map_path,map_name)
+    new_file = Path(map_path,name)
+    os.rename(old_file,new_file)
+    return map_name
\ No newline at end of file
